@@ -2,7 +2,7 @@
 # Distribution : HiPi Modules for Raspberry Pi
 # File         : lib/HiPi/RaspberryPi.pm
 # Description  : Information about host Raspberry Pi
-# Copyright    : Copyright (c) 2013-2020 Mark Dootson
+# Copyright    : Copyright (c) 2013-2023 Mark Dootson
 # License      : This is free software; you can redistribute it and/or modify it under
 #                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
@@ -14,7 +14,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION ='0.83';
+our $VERSION ='0.86';
 
 my ( $btype1, $btype2, $btype3, $btype4) = ( 1, 2, 3, 4 );
 
@@ -223,7 +223,7 @@ my %_revinfostash = (
         '15' => 'UNKNOWN Rasberry Pi Model 15',         # 0F
         '16' => 'Raspberry Pi Compute Module 3 Plus',   # 10
         '17' => 'Raspberry Pi 4 Model B',               # 11
-        '18' => 'UNKNOWN Rasberry Pi Model 18',         # 12
+        '18' => 'Raspberry Pi Zero 2',                  # 12
         '19' => 'Raspberry Pi Model 400',               # 13
         '20' => 'Raspberry Pi Compute Module 4',        # 14
     },
@@ -269,7 +269,7 @@ my %_revinfostash = (
         '15' => 'unknown',
         '16' => 'Q1 2019',
         '17' => 'Q2 2019',
-        '18' => 'unknown',
+        '18' => 'Q4 2021',
         '19' => 'Q4 2020',
         '20' => 'Q4 2020',
     },
@@ -391,20 +391,27 @@ sub _configure {
     } else {
         # is this a scheme 0 or 1 number
         my $revnum = oct( '0x' . $rev );
-        
+        #          NOQuuuWuFMMMCCCCPPPPTTTTTTTTRRRR
         my $schemenewt = 0b100000000000000000000000 & $revnum;
         $schemenewt = $schemenewt >> 23;
         
         if ( $schemenewt ) {
-            my $schemerev = 0b1111 & $revnum;
-            my $schemetype = 0b111111110000 & $revnum;
-            $schemetype = $schemetype >> 4;
-            my $schemeproc = 0b1111000000000000 & $revnum;
-            $schemeproc = $schemeproc >> 12;
-            my $schememanu = 0b11110000000000000000 & $revnum;
-            $schememanu = $schememanu >> 16;
-            my $schemesize = 0b11100000000000000000000 & $revnum;
-            $schemesize = $schemesize >> 20;
+            # revision         RRRR
+            my $schemerev  = 0b1111 & $revnum;
+            # raspberry type     TTTTTTTTRRRR
+            my $schemetype = ( 0b111111110000 & $revnum ) >> 4;
+            # processor          PPPPTTTTTTTTRRRR
+            my $schemeproc = ( 0b1111000000000000 & $revnum) >> 12;
+            # manufacturer       CCCCPPPPTTTTTTTTRRRR
+            my $schememanu = ( 0b11110000000000000000 & $revnum ) >> 16;
+            # memory             MMMCCCCPPPPTTTTTTTTRRRR
+            my $schemesize = ( 0b11100000000000000000000 & $revnum ) >> 20;           
+            # other bits         NOQuuuWuFMMMCCCCPPPPTTTTTTTTRRRR
+            # my $schemerest = 0b11100010000000000000000000000000 & $revnum;
+            my $schemewarranty = ( $revnum >> 25 ) & 1;
+            my $schemeotpread  = ( $revnum >> 29 ) & 1;
+            my $schemeotpprog  = ( $revnum >> 30 ) & 1;
+            my $schemevolt     = ( $revnum >> 31 ) & 1;
             
             # base type
             my $binfo = $_revstash{$defaultkey};
@@ -420,7 +427,7 @@ sub _configure {
             $binfo->{revisionnumber} = $schemerev;
             
             $israspberry2 = ( $schemetype == 4 ) ? 1 : 0;
-            $israspberry3 = ( $schemetype == 8 || $schemetype == 10 || $schemetype == 13 || $schemetype == 14 || $schemetype == 16 ) ? 1 : 0;
+            $israspberry3 = ( $schemetype == 8 || $schemetype == 10 || $schemetype == 13 || $schemetype == 14 || $schemetype == 16 || $schemetype == 18 ) ? 1 : 0;
             $israspberry4 = ( $schemetype == 17 ) ? 1 : 0;
             
             $_config = { %$binfo };
